﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace SASrecorder
{
    public partial class Form1 : Form
    {
        private System.IO.Ports.SerialPort NTL_SerialPort = new System.IO.Ports.SerialPort();
        private string COMPORT = ""; //【ポート番号】
        private string RxMsg = "";   //【受信メッセージ】
        private int NTL_Ch = 0;      //【Ch0】
        private int NTL_Count = 0;   //【サンプル番号】
        private string NTL_Log = ""; //【サンプルログ】
        private string NTL_Disp = "";

        public Form1()
        {
            InitializeComponent();
            timer1.Interval = 100;
            timer1.Tick += new EventHandler(timer1_Tick);
            timer1.Enabled = true;
            this.FormClosing += new FormClosingEventHandler(Form1_FormClosing);
            InitSerialPort();
            NTL_SerialPort.DataReceived += new System.IO.Ports.SerialDataReceivedEventHandler(NTL_SerialPort_DataReceived);
        }

        void timer1_Tick(object sender, EventArgs e)
        {
            if (NTL_Disp != "") textBox1.Text = NTL_Disp;
        }

        void NTL_SerialPort_DataReceived(object sender, System.IO.Ports.SerialDataReceivedEventArgs e)
        {
            Int32 ADcount = 0;
            try { RxMsg = NTL_SerialPort.ReadTo("\r"); } //【受信】
            catch { RxMsg = "000000"; }
            if (RxMsg.Length > 6) RxMsg = RxMsg.Substring(RxMsg.Length-6, 6);
            ADcount = Convert.ToInt32(RxMsg, 16); //★Convertクラスを使って16進数を符号付き整数として変換する
            if ((ADcount & 0x800000) > 0) ADcount -= 0x1000000;
            if (NTL_Ch == 0)
            {
                NTL_Ch = 1;
                NTL_SerialPort.Write("C105082\r\n");  //【入力】チャンネル2(サーミスタ)
                NTL_Log += NTL_Count.ToString() + ", " + ADcount.ToString() + ", ";
            }
            else
            {
                NTL_Ch = 0;
                NTL_SerialPort.Write("C105080\r\n");     //【入力】チャンネル0 (いびき)
                NTL_Log +=  ADcount.ToString() + "\r\n";
                if (NTL_Count == 1000) NTL_Disp = NTL_Log;
                NTL_Count++;
            }
            System.Threading.Thread.Sleep(5);        //【待機】5m秒
            RxMsg = NTL_SerialPort.ReadTo("\r");
            NTL_SerialPort.Write("R\r\n");     //【送信】次のAD変換結果を要求する【次回取得】
        }

        void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            if(COMPORT != "")
            {
                NTL_SerialPort.Write("C08600A\r\n");     //【送信】パワーダウンモード
                System.Threading.Thread.Sleep(5);        //【待機】5m秒
                RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】
                NTL_SerialPort.Close();
            } //【ポートを閉じる】
        }

        private void button1_Click(object sender, EventArgs e)
        {
            NTL_Count = 0;
            NTL_Ch = 0;
            NTL_Log = "";
            NTL_Disp = "";
            NTL_SerialPort.Write("C105080\r\n");     //【入力】チャンネル0 (いびき)
            System.Threading.Thread.Sleep(5);        //【待機】5m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】
            NTL_SerialPort.Write("R\r\n");           //【送信】次のAD変換結果を要求する【次回取得】
        }

        private void InitSerialPort()
        {
            string[] pn = System.IO.Ports.SerialPort.GetPortNames(); //【接続されているポートの名称を取得する】
            if (pn.Length == 0)
            {
                MessageBox.Show(
                   "接続可能なシリアル通信ポートが見当たりません。",
                   "KINECT for Windows Error Message",
                   MessageBoxButtons.OK
                );
                return;
            }
            COMPORT = pn[0]; //【一つしかシリアルポートが接続されていない前提で選択】
            NTL_SerialPort.PortName = COMPORT;
            NTL_SerialPort.ReadTimeout = 50;      //【Timeout 50mS】
            NTL_SerialPort.ReadBufferSize = 256;  //【受信バッファサイズ】
            NTL_SerialPort.WriteBufferSize = 256; //【送信バッファサイズ】
            try { NTL_SerialPort.Open(); }
            catch (Exception) { MessageBox.Show("シリアルポートが開けません"); return; }

            //【接続確認】特に値のチェックなどはしていません。
            NTL_SerialPort.Write("E\r\n");       //【送信】"E"+CR+LF 【接続確認コマンド】
            System.Threading.Thread.Sleep(50);   //【待機】50m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】
            //【ADCモードレジスタ書込み】0001　ADC変換レートを(125Hzに)設定する。
            // ADCの変換速度は適宜変更してください。
            NTL_SerialPort.Write("C080001\r\n");  //【送信】"C08"+"0001"+CR+LF 500Hz
            // NTL_SerialPort.Write("C080002\r\n");  //【送信】"C08"+"0002"+CR+LF 250Hz
            // NTL_SerialPort.Write("C080003\r\n");  //【送信】"C08"+"0003"+CR+LF 125Hz
            // NTL_SerialPort.Write("C080004\r\n");  //【送信】"C08"+"0004"+CR+LF 62.5Hz
            // NTL_SerialPort.Write("C080005\r\n");  //【送信】"C08"+"0005"+CR+LF 50Hz
            // NTL_SerialPort.Write("C080006\r\n");  //【送信】"C08"+"0006"+CR+LF 39.2Hz
            // NTL_SerialPort.Write("C080007\r\n");  //【送信】"C08"+"0007"+CR+LF 33.3Hz
            System.Threading.Thread.Sleep(50);       //【待機】50m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】

            //【ADC設定レジスタ書込み】5080 【コマンド】C105080 + CR + LF
            NTL_SerialPort.Write("C105080\r\n");     //【入力】チャンネル0 (いびき)
            // NTL_SerialPort.Write("C105081\r\n");  //【入力】チャンネル1(照度)
            // NTL_SerialPort.Write("C105082\r\n");  //【入力】チャンネル2(サーミスタ)
            // NTL_SerialPort.Write("C105086\r\n");  //【入力】内蔵温度センサ
            System.Threading.Thread.Sleep(50);       //【待機】50m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】

            //【IOレジスタ】0A　【コマンド】C280A + CR + LF
            NTL_SerialPort.Write("C280A\r\n");       //【送信】電流源は未使用
            System.Threading.Thread.Sleep(50);       //【待機】50m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】

            //【ADCオフセットレジスタ】800000 【コマンド】C30800000 + CR + LF
            NTL_SerialPort.Write("C30800000\r\n");   //【送信】
            System.Threading.Thread.Sleep(50);       //【待機】50m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】
            NTL_SerialPort.Write("PM80\r\n"); //【送信】
            System.Threading.Thread.Sleep(50);       //【待機】50m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】
            NTL_SerialPort.Write("PW0F\r\n");        //【送信】
            System.Threading.Thread.Sleep(3000);     //【待機】3000m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】
            NTL_SerialPort.Write("PW00\r\n");        //【送信】
            System.Threading.Thread.Sleep(50);       //【待機】50m秒
            RxMsg = NTL_SerialPort.ReadTo("\r\n\0"); //【受信】

            NTL_SerialPort.DiscardInBuffer();        //【バッファ内データを破棄する】
            System.Threading.Thread.Sleep(5);        //【待機】5m秒
            NTL_SerialPort.Write("R\r\n");           //【送信】AD変換結果を要求する
        }
    }
}
